@@ -6,6 +6,9 @@ use warnings;
 
 use base 'Exporter';
 use Csistck::Oper;
+use Csistck::Test::Return;
+
+use Scalar::Util qw/blessed/;
 
 sub new {
     my $class = shift;
@@ -19,11 +22,11 @@ sub new {
     }, $class;
 }
 
-sub desc { $_[0]->{desc}; }
-sub target { $_[0]->{target}; }
+sub desc { shift->{desc}; }
+sub target { shift->{target}; }
 
 sub on_repair { 
-    my $func = $_[0]->{on_repair};
+    my $func = shift->{on_repair};
     return $func if (ref $func eq 'CODE');
 }
 
@@ -34,7 +37,11 @@ sub execute {
     # We will exit with pass here, as to not throw an error. It is not the fault
     # of the user if the test has no check or repair operation
     my $func = sub {};
-    return 1 unless ($self->can($mode));
+    unless ($self->can($mode)) {
+        return $self->fail('Test missing mode');
+        # TODO make this better error
+    };
+
     given ($mode) {
         when ("check") { $func = sub { $self->check } if ($self->can('check')); }
         when ("repair") { $func = sub { $self->repair } if ($self->can('repair')); }
@@ -42,17 +49,36 @@ sub execute {
     }
 
     Csistck::Oper::info($self->desc);
-    eval { &{$func}; };
+    my $ret = eval { &{$func}; };
     
+    # Catch errors
     if ($@) {
         my $error = $@;
         $error =~ s/ at [A-Za-z0-9\/\_\-\.]+ line [0-9]+.\n//;
         Csistck::Oper::error(sprintf("%s: %s", $self->desc, $error));
-        return 0;
+        return $self->fail($error);
+    }
+    
+    # Return should be an object from now on. If not blessed, assume ret value
+    if (blessed($ret) and $ret->isa('Csistck::Test::Return')) {
+        Csistck::Oper::info($ret->msg);
+        return $ret;
     }
     else {
-        return 1;
+        return $self->ret($ret, "Test response");
     }   
 }
 
+# Return test response
+sub ret {
+    my ($self, $resp, $msg) = @_;
+    return Csistck::Test::Return->new(
+        desc => $self->desc,
+        resp => $resp,
+        msg => $msg
+    );
+}
+sub fail { shift->ret(0, @_); }
+sub pass { shift->ret(1, @_); }
+
 1;
